#!$CLEARCASE/bin/ccperl.exe

# ciCobol.pl - Post-op trigger on CheckIn
#
# Authors:  Brandt Onorato, Steve Seifert, Tony Lee, Rich Ralston, Ray Green
# Last updated:  Steve Seifert, 9/14/06
#
# (c) Copyright IBM Corp. 2008
#
# The common routines used in all the build scripts are contained in the 
# bccpbmod.pm module.
#
# All COBOL SOURCE files and COPY BOOK files are transferred to the mainframe on checkin when
# operating in the DEV environment.  This trigger exits when the parent operation is either
# a delivery or rebase.  
#
# The environment information is held in an Attribute attached to any/every
# Z-enabled ClearCase UCM Project.  The common module setEnvironmentVar determines
# the Project from the target stream.
#
# This trigger script can be limited to specific users during development by using the
# following lines and changing the username strings.
# In this example an user id table 'userid' is used and queried from bccpbmod.pm.
# If using your site security system, this step may be skipped.
#
# my $user = $ENV{'USERNAME'};
# exit 0 if ((lc $user ne "USER1") && (lc $user ne "USER2"));
#
# You must modify this script before attempting to use parameterized build.
# Sections that require modification and the instructions for modifying them
# are flagged with the following comment lines:
#
# ******************************************************************************
# * Customization instructions:                                                *
# * [instructions here]                                                        *
# ******************************************************************************

print "ciCobol.pl\n";



# Exit trigger if the parent operation is a delivery or rebase.
my $popKind  = $ENV{CLEARCASE_POP_KIND};
exit 0 if (($popKind eq "deliver_complete") || ($popKind eq "rebase_complete"));


require File::Basename;
require bccpbmod;

my $status = 0;
my $compile_1 = "";

# #############################################################################
# Identify the element name and the environment where the trigger
# was fired.  The target stream is used to get the mainframe
# environment. The command line yes/no info is used to choose
# the proper final message medium (stdout or clearprompt).
#
my $elem     = $ENV{'CLEARCASE_PN'};
my $from_ct  = $ENV{CLEARCASE_CMDLINE};

# *******************************************************************************
# * Optional customization:                                                     *
# * You can use the optional variables or add new variables based on your site's*
# * needs.  If you determine to use the optional variables or add new variables,*
# * you have to update all related scripts correspondently.                     *
# *******************************************************************************
my ($env, $db2sys, $menv, $os390_hostname, $os390_port, $stage,
    $copylib1, $copylib2, $copylib3, $copylib4,
    $syslib1, $syslib2, $syslib3,
#    $syslib4, $steplib1, $steplib2,			 # optional
#    $hostpds_prefix, $hostpds_affix, $cbllib,	         # optional 
    $loadlib, $c390llib, $dbrmlib, $tgtlib, $db2_owner) =
  bccpbmod::setEnvironmentVar();

# #############################################################################
# Exit trigger if the file is not a COBOL SOURCE or COPY BOOK
#
my $ext = "";
($file,$path,$ext) = File::Basename::fileparse($elem,qr{\.CPY});
my $filename = $file . $ext;
exit 0 if (($ext ne "CPY") && ($ext ne "CBL"));

# #############################################################################
# Transfer only if a valid file extension is found and the checkin
# is begin performed in the DEV environment.
#
if (($ext ne "") && ($env eq "DEV")) {

# #############################################################################
# Translate the distributed username to a mainframe ID
#
	my $pcid = $ENV{USERNAME};
	my $mfid = bccpbmod::getUserID($pcid);

# #############################################################################
# Set the directory for log files
# This can be changed per installation
#
	my $jcldir = "c:\\temp\\$mfid";
	mkdir $jcldir if (!(-d $jcldir));

# #############################################################################
# Build the JCL that will be used to transfer the file
#
	my $jcl = "$jcldir\\ciCobol.jcl";
	unlink $jcl;

	bccpbmod::writeFile($jcl, $compile_1, "
//* ------------------------------------------------------------------
//CICOBOL  EXEC PGM=IEFBR14
//*        ----
//*        ---- IEFBR14 - Upload and Allocate Temporary Files
//*        ----
//UPLD1    DD  DSN=$tgtlib,RCCEXT=CPY,DISP=SHR
//* ------------------------------------------------------------------
"
	);

# #############################################################################
# Open log and output files to collect execution info
#
	my $rcc = "$jcldir\\rcc.out";
	my $log = "$jcldir\\ciCobol.log";
	unlink $rcc;
	unlink $log;

	open LOG, "> $log" or die "Can't open $log: $!";

# #############################################################################
# Upload and execute the JCL for the copy book or cobol source
# The $tgtlib variable contains the destination library and is part of the JCL
# The $elem variable contains the file to be transferred and is part of the rccbuild argument list
#
	my $cmd = "$bccpbmod::rccbuild -h $os390_hostname\@$os390_port -b CICOBOL -ft $jcl -i $elem -n 0 -c LE >$rcc";
	print LOG "Step: ciCobol cmd: $cmd\n " if $debug;
	$status = system($cmd);
	print LOG "Element: $filename, Status: $status\n";

	print LOG "Successful copy of CopyBook\n" if ($status == 0);

	close LOG;

# #############################################################################
# Report the results
#
	if ($from_ct) {
		print "Successful copy of CopyBook: $filename\n" if ($status == 0);
	} else {
		$cmd = "clearprompt proceed -prompt \"Successful copy of CopyBook: $filename\"";
		$status = system($cmd) if ($status == 0);
	}
}

exit $status;
